@@ -90,7 +90,7 @@ print "
  cc='$Config{cc}', optimize='$Config{optimize}'
  ccflags ='$Config{ccflags}'
 
- Please mail benchmark results to gbarr\@pobox.com.  Thanks!
+ Please mail benchmark results to perl-loop\@perl.org.  Thanks!
 
 Elapse Time:     ".pct($elapse,$TestTime)." of $TestTime seconds
 Timer/sec:       ".pct($TimerCount,$TimerExpect)." ($TimerCount total)
